.. Gpxity documentation master file, created by
   sphinx-quickstart on Tue Feb 14 09:25:08 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Gpxity's documentation!
==================================

.. include:: ../../README.rst


.. include:: modules.rst


.. include:: ../../CHANGELOG.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

License: GPL v2
